@@ -27,6 +27,11 @@ def sensitivity(var, xlabel="time", model=None, var0=None, t =None, param=None,
     Returns:
         array:  Sensitivity of solved results to parameter - par.
     """
+    if isinstance(param, int) | isinstance(param, float):
+        param = [param]
+    if isinstance(param_var0, int) | isinstance(param_var0, float):
+        param_var0 = [param_var0]
+    
     if param_var0 != None:
 
         # solve the ode function using the initial input parameter
