@@ -23,7 +23,9 @@ def sol_ode(model, var0, t, param):
     """
     dt = t[1]-t[0]
     if isinstance(param,list):
-        param = np.array(param)
+        if (len(param) == 1):
+            param = param[0]
+        else: pass
     else: pass
 
     if isinstance(var0,list):
